==> openshift-model-hive-5.12.2-sources.jar: io/fabric8/openshift/api/model/hive/v1/ClusterDeploymentStatusBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class ClusterDeploymentStatusBuilder extends io.fabric8.openshift.api.model.hive.v1.ClusterDeploymentStatusFluentImpl<io.fabric8.openshift.api.model.hive.v1.ClusterDeploymentStatusBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.hive.v1.ClusterDeploymentStatus,io.fabric8.openshift.api.model.hive.v1.ClusterDeploymentStatusBuilder>{
  public ClusterDeploymentStatusBuilder() {
    this(false);
  }
  public ClusterDeploymentStatusBuilder(java.lang.Boolean validationEnabled) {
    this(new ClusterDeploymentStatus(), validationEnabled);
  }
  public ClusterDeploymentStatusBuilder(io.fabric8.openshift.api.model.hive.v1.ClusterDeploymentStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public ClusterDeploymentStatusBuilder(io.fabric8.openshift.api.model.hive.v1.ClusterDeploymentStatusFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new ClusterDeploymentStatus(), validationEnabled);
  }
  public ClusterDeploymentStatusBuilder(io.fabric8.openshift.api.model.hive.v1.ClusterDeploymentStatusFluent<?> fluent,io.fabric8.openshift.api.model.hive.v1.ClusterDeploymentStatus instance) {
    this(fluent, instance, false);
  }
  public ClusterDeploymentStatusBuilder(io.fabric8.openshift.api.model.hive.v1.ClusterDeploymentStatusFluent<?> fluent,io.fabric8.openshift.api.model.hive.v1.ClusterDeploymentStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiURL(instance.getApiURL()); 
    fluent.withCertificateBundles(instance.getCertificateBundles()); 
    fluent.withCliImage(instance.getCliImage()); 
    fluent.withConditions(instance.getConditions()); 
    fluent.withInstallRestarts(instance.getInstallRestarts()); 
    fluent.withInstallStartedTimestamp(instance.getInstallStartedTimestamp()); 
    fluent.withInstallVersion(instance.getInstallVersion()); 
    fluent.withInstalledTimestamp(instance.getInstalledTimestamp()); 
    fluent.withInstallerImage(instance.getInstallerImage()); 
    fluent.withPlatformStatus(instance.getPlatformStatus()); 
    fluent.withPowerState(instance.getPowerState()); 
    fluent.withProvisionRef(instance.getProvisionRef()); 
    fluent.withWebConsoleURL(instance.getWebConsoleURL()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ClusterDeploymentStatusBuilder(io.fabric8.openshift.api.model.hive.v1.ClusterDeploymentStatus instance) {
    this(instance,false);
  }
  public ClusterDeploymentStatusBuilder(io.fabric8.openshift.api.model.hive.v1.ClusterDeploymentStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiURL(instance.getApiURL()); 
    this.withCertificateBundles(instance.getCertificateBundles()); 
    this.withCliImage(instance.getCliImage()); 
    this.withConditions(instance.getConditions()); 
    this.withInstallRestarts(instance.getInstallRestarts()); 
    this.withInstallStartedTimestamp(instance.getInstallStartedTimestamp()); 
    this.withInstallVersion(instance.getInstallVersion()); 
    this.withInstalledTimestamp(instance.getInstalledTimestamp()); 
    this.withInstallerImage(instance.getInstallerImage()); 
    this.withPlatformStatus(instance.getPlatformStatus()); 
    this.withPowerState(instance.getPowerState()); 
    this.withProvisionRef(instance.getProvisionRef()); 
    this.withWebConsoleURL(instance.getWebConsoleURL()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.hive.v1.ClusterDeploymentStatusFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.hive.v1.ClusterDeploymentStatus build() {
    ClusterDeploymentStatus buildable = new ClusterDeploymentStatus(fluent.getApiURL(),fluent.getCertificateBundles(),fluent.getCliImage(),fluent.getConditions(),fluent.getInstallRestarts(),fluent.getInstallStartedTimestamp(),fluent.getInstallVersion(),fluent.getInstalledTimestamp(),fluent.getInstallerImage(),fluent.getPlatformStatus(),fluent.getPowerState(),fluent.getProvisionRef(),fluent.getWebConsoleURL());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ClusterDeploymentStatusBuilder that = (ClusterDeploymentStatusBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-hive-6.6.0-sources.jar: io/fabric8/openshift/api/model/hive/v1/ClusterDeploymentStatusBuilder.java <==
package io.fabric8.openshift.api.model.hive.v1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class ClusterDeploymentStatusBuilder extends ClusterDeploymentStatusFluentImpl<ClusterDeploymentStatusBuilder> implements VisitableBuilder<ClusterDeploymentStatus,ClusterDeploymentStatusBuilder>{
  public ClusterDeploymentStatusBuilder() {
    this(false);
  }
  public ClusterDeploymentStatusBuilder(Boolean validationEnabled) {
    this(new ClusterDeploymentStatus(), validationEnabled);
  }
  public ClusterDeploymentStatusBuilder(ClusterDeploymentStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public ClusterDeploymentStatusBuilder(ClusterDeploymentStatusFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new ClusterDeploymentStatus(), validationEnabled);
  }
  public ClusterDeploymentStatusBuilder(ClusterDeploymentStatusFluent<?> fluent,ClusterDeploymentStatus instance) {
    this(fluent, instance, false);
  }
  public ClusterDeploymentStatusBuilder(ClusterDeploymentStatusFluent<?> fluent,ClusterDeploymentStatus instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiURL(instance.getApiURL()); 
    fluent.withCertificateBundles(instance.getCertificateBundles()); 
    fluent.withCliImage(instance.getCliImage()); 
    fluent.withConditions(instance.getConditions()); 
    fluent.withInstallRestarts(instance.getInstallRestarts()); 
    fluent.withInstallStartedTimestamp(instance.getInstallStartedTimestamp()); 
    fluent.withInstallVersion(instance.getInstallVersion()); 
    fluent.withInstalledTimestamp(instance.getInstalledTimestamp()); 
    fluent.withInstallerImage(instance.getInstallerImage()); 
    fluent.withPlatformStatus(instance.getPlatformStatus()); 
    fluent.withPowerState(instance.getPowerState()); 
    fluent.withProvisionRef(instance.getProvisionRef()); 
    fluent.withWebConsoleURL(instance.getWebConsoleURL()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public ClusterDeploymentStatusBuilder(ClusterDeploymentStatus instance) {
    this(instance,false);
  }
  public ClusterDeploymentStatusBuilder(ClusterDeploymentStatus instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiURL(instance.getApiURL()); 
    this.withCertificateBundles(instance.getCertificateBundles()); 
    this.withCliImage(instance.getCliImage()); 
    this.withConditions(instance.getConditions()); 
    this.withInstallRestarts(instance.getInstallRestarts()); 
    this.withInstallStartedTimestamp(instance.getInstallStartedTimestamp()); 
    this.withInstallVersion(instance.getInstallVersion()); 
    this.withInstalledTimestamp(instance.getInstalledTimestamp()); 
    this.withInstallerImage(instance.getInstallerImage()); 
    this.withPlatformStatus(instance.getPlatformStatus()); 
    this.withPowerState(instance.getPowerState()); 
    this.withProvisionRef(instance.getProvisionRef()); 
    this.withWebConsoleURL(instance.getWebConsoleURL()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  ClusterDeploymentStatusFluent<?> fluent;
  Boolean validationEnabled;
  public ClusterDeploymentStatus build() {
    ClusterDeploymentStatus buildable = new ClusterDeploymentStatus(fluent.getApiURL(),fluent.getCertificateBundles(),fluent.getCliImage(),fluent.getConditions(),fluent.getInstallRestarts(),fluent.getInstallStartedTimestamp(),fluent.getInstallVersion(),fluent.getInstalledTimestamp(),fluent.getInstallerImage(),fluent.getPlatformStatus(),fluent.getPowerState(),fluent.getProvisionRef(),fluent.getWebConsoleURL());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
